==> jxbase-2.13.zip: jxbase-2.13/jxbase/common_import.py <==
#coding=utf-8

#from __future__ import division

# ----------------------
# 这两个 import 先写，后面这个 for 要用到他们

try:
	from importlib import import_module
except:
	print('请先到命令行下：pip install importlib，安装完成后，再重新执行本程序。')
	exit()

try:	
	import os
except:
	print('请先到命令行下：pip install os，安装完成后，再重新执行本程序。')
	exit()

from jxbase import common_config as cf
# =============================




# -----------------
# 这个 for 是用来 import 上述 list 中各模块，若不存在，则调用 pip install 到网上拉取安装

for k,module in enumerate(cf.MODULES_ARR):
	try:
		# 这两句作用是相同的，都是 import 模块，随便用哪句都可以，但感觉用 locals() 那句更优雅些，无需像第一句那样拼接字符串，但第1句也是正确的
		#exec("%s = import_module('%s')" % (module,module))
		locals()[module] = import_module(module) 			# 这句用法非常好，可以让字符串当作变量使用，不只是在这种import 情形下，在许多需要字符串当变量的地方都可以使用。
	except:
		try:
			cmd_pip = "pip install %s" % (module)
			os.system(cmd_pip)
		except:
			print("----Failed pip install %s" % (module))
		else:
			print("----pip install %s successfully. and will import it now." % (module))
			locals()[module] = import_module(module)
			print('----After pip and import %s successfully.' % (module))

# ====================================

# 以下各包的主体名必须已出现在 cf.MODULE_ARR 中，否则下面要出错

import matplotlib.pyplot as plt
import matplotlib.finance as mpf
import numpy as np
import pandas as pd
import scipy as sp
import tkinter as tk


from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.mime.image import MIMEImage  
from email.header import Header  
from email.utils import formataddr


#from matplotlib import pylab 	# 因为上面有单独对 pylab 的引用，和这里的  pylab 是同一个东西
from scipy.optimize import leastsq  # 引入最小二乘函数  
#from Crypto.Cipher import AES
from binascii import b2a_hex, a2b_hex
from sqlalchemy import *
from pandas import Series,DataFrame
from ftplib import FTP 
from lxml import etree
from bs4 import BeautifulSoup as bs
from PIL import Image

from configobj import ConfigObj



############# 以下的模块没有包含在 Anaconda3 中，是后来自己安装的 #################
import pymysql
#import MySQLdb
import tushare as ts
#import easytrader 
#import tensorflow as tf
#import chardet
import pytesseract
import redis
import django
import pywinauto

from pywinauto import application
from pywinauto import clipboard



from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.keys import Keys

from apscheduler.schedulers.background import BackgroundScheduler 			# 这里引入的是函数，并非模块，是查阅该模块API文档后才知道的
from apscheduler.schedulers.blocking import BlockingScheduler 				# 这里引入的是函数，并非模块，是查阅该模块API文档后才知道的
from apscheduler.executors.pool import ThreadPoolExecutor, ProcessPoolExecutor 			# 这里引入的是函数，并非模块，是查阅该模块API文档后才知道的
import apscheduler.events

==> jxbase-2.15.zip: jxbase-2.15/jxbase/common_import.py <==
#coding=utf-8

#from __future__ import division

# ----------------------
# 这两个 import 先写，后面这个 for 要用到他们

try:
	from importlib import import_module
except:
	print('请先到命令行下：pip install importlib，安装完成后，再重新执行本程序。')
	exit()

try:	
	import os
except:
	print('请先到命令行下：pip install os，安装完成后，再重新执行本程序。')
	exit()

from jxbase import common_config as cf
# =============================




# -----------------
# 这个 for 是用来 import 上述 list 中各模块，若不存在，则调用 pip install 到网上拉取安装

for k,module in enumerate(cf.MODULES_ARR):
	try:
		# 这两句作用是相同的，都是 import 模块，随便用哪句都可以，但感觉用 locals() 那句更优雅些，无需像第一句那样拼接字符串，但第1句也是正确的
		#exec("%s = import_module('%s')" % (module,module))
		locals()[module] = import_module(module) 			# 这句用法非常好，可以让字符串当作变量使用，不只是在这种import 情形下，在许多需要字符串当变量的地方都可以使用。
	except:
		try:
			cmd_pip = "pip install %s" % (module)
			os.system(cmd_pip)
		except:
			print("----Failed pip install %s" % (module))
		else:
			print("----pip install %s successfully. and will import it now." % (module))
			locals()[module] = import_module(module)
			print('----After pip and import %s successfully.' % (module))

# ====================================

# 以下各包的主体名必须已出现在 cf.MODULE_ARR 中，否则下面要出错

#import matplotlib.pyplot as plt
#import matplotlib.finance as mpf
import numpy as np
import pandas as pd
#import scipy as sp
#import tkinter as tk


from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.mime.image import MIMEImage  
from email.header import Header  
from email.utils import formataddr


#from matplotlib import pylab 	# 因为上面有单独对 pylab 的引用，和这里的  pylab 是同一个东西
#from scipy.optimize import leastsq  # 引入最小二乘函数  
#from Crypto.Cipher import AES
#from binascii import b2a_hex, a2b_hex
#from sqlalchemy import *
from pandas import Series,DataFrame
from ftplib import FTP 
#from lxml import etree
#from bs4 import BeautifulSoup as bs
from PIL import Image

from configobj import ConfigObj



############# 以下的模块没有包含在 Anaconda3 中，是后来自己安装的 #################
#import pymysql
#import MySQLdb
#import tushare as ts
#import easytrader 
#import tensorflow as tf
#import chardet
import pytesseract
#import redis
#import django
import pywinauto

from pywinauto import application
from pywinauto import clipboard


'''
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.keys import Keys

from apscheduler.schedulers.background import BackgroundScheduler 			# 这里引入的是函数，并非模块，是查阅该模块API文档后才知道的
from apscheduler.schedulers.blocking import BlockingScheduler 				# 这里引入的是函数，并非模块，是查阅该模块API文档后才知道的
from apscheduler.executors.pool import ThreadPoolExecutor, ProcessPoolExecutor 			# 这里引入的是函数，并非模块，是查阅该模块API文档后才知道的
import apscheduler.events
'''
